@@ -10,6 +10,8 @@ from typing import Any
 
 import cv2
 import numpy as np
+import shapely
+import trimesh
 from tqdm import tqdm
 from trimesh import Trimesh
 
@@ -144,7 +146,7 @@ class Background(MeshComponent, ImageComponent):
                 self.logger.debug("Could not create mask for building with error: %s", e)
                 continue
 
-            mean_value = cv2.mean(dem_image, mask=mask)[0]
+            mean_value = cv2.mean(dem_image, mask=mask)[0]  # type: ignore
             mean_value = np.round(mean_value).astype(dem_image.dtype)
             self.logger.debug("Mean value of the building area: %s", mean_value)
 
@@ -231,13 +233,13 @@ class Background(MeshComponent, ImageComponent):
         if self.map.output_size is not None:
             scaled_background_size = int(self.background_size * self.map.size_scale)
             dem_data = cv2.resize(
-                dem_data,
+                dem_data,  # type: ignore
                 (scaled_background_size, scaled_background_size),
                 interpolation=cv2.INTER_NEAREST,
             )
 
         self.plane_from_np(
-            dem_data,
+            dem_data,  # type: ignore
             save_path,
             create_preview=True,
             remove_center=self.map.background_settings.remove_center,
@@ -255,7 +257,7 @@ class Background(MeshComponent, ImageComponent):
         """
         dem_data = cv2.imread(dem_path, cv2.IMREAD_UNCHANGED)
         half_size = self.map_size // 2
-        dem_data = self.cut_out_np(dem_data, half_size, return_cutout=True)
+        dem_data = self.cut_out_np(dem_data, half_size, return_cutout=True)  # type: ignore
 
         if save_path:
             cv2.imwrite(save_path, dem_data)
@@ -362,7 +364,7 @@ class Background(MeshComponent, ImageComponent):
         background_dem_preview_image = cv2.imread(self.output_path, cv2.IMREAD_UNCHANGED)
 
         background_dem_preview_image = cv2.resize(
-            background_dem_preview_image, (0, 0), fx=1 / 4, fy=1 / 4
+            background_dem_preview_image, (0, 0), fx=1 / 4, fy=1 / 4  # type: ignore
         )
         background_dem_preview_image = cv2.normalize(
             background_dem_preview_image,
@@ -411,7 +413,7 @@ class Background(MeshComponent, ImageComponent):
         self.logger.debug("Creating grayscale preview of DEM data in %s.", grayscale_dem_path)
 
         dem_data = cv2.imread(image_path, cv2.IMREAD_GRAYSCALE)
-        dem_data_rgb = cv2.cvtColor(dem_data, cv2.COLOR_GRAY2RGB)
+        dem_data_rgb = cv2.cvtColor(dem_data, cv2.COLOR_GRAY2RGB)  # type: ignore
         cv2.imwrite(grayscale_dem_path, dem_data_rgb)
         return grayscale_dem_path
 
@@ -435,7 +437,7 @@ class Background(MeshComponent, ImageComponent):
         dem_data_normalized = np.empty_like(dem_data)
 
         # Normalize the DEM data to the range [0, 255]
-        cv2.normalize(dem_data, dem_data_normalized, 0, 255, cv2.NORM_MINMAX)
+        cv2.normalize(dem_data, dem_data_normalized, 0, 255, cv2.NORM_MINMAX)  # type: ignore
         dem_data_colored = cv2.applyColorMap(dem_data_normalized, cv2.COLORMAP_JET)
 
         cv2.imwrite(colored_dem_path, dem_data_colored)
@@ -470,6 +472,7 @@ class Background(MeshComponent, ImageComponent):
             logger=self.logger,
             texture_custom_schema=background_layers,  # type: ignore
             skip_scaling=True,  # type: ignore
+            info_layer_path=os.path.join(self.info_layers_directory, "background.json"),  # type: ignore
         )
 
         self.background_texture.preprocess()
@@ -513,8 +516,8 @@ class Background(MeshComponent, ImageComponent):
         )
 
         dem_image = self.subtract_by_mask(
-            dem_image,
-            water_resources_image,
+            dem_image,  # type: ignore
+            water_resources_image,  # type: ignore
             int(self.map.dem_settings.water_depth * z_scaling_factor),
         )
 
@@ -534,8 +537,148 @@ class Background(MeshComponent, ImageComponent):
 
         return blur_power
 
+    def generate_linebased_water(self) -> None:
+        """Generates water resources based on line-based polylines from the background info layer.
+        It creates polygons from the polylines, fits them into the map bounds, and generates a mesh.
+        """
+        self.logger.debug("Starting line-based water generation...")
+
+        water_polylines = self.get_infolayer_data(Parameters.BACKGROUND, Parameters.WATER_POLYLINES)
+        self.logger.debug(
+            "Found %s water polylines in background info layer.", len(water_polylines)  # type: ignore
+        )
+        if not water_polylines:
+            self.logger.warning("No water polylines found in background info layer.")
+            return
+
+        polygons: list[shapely.Polygon] = []
+        for polyline in water_polylines:
+            points = polyline["points"]
+            width = polyline["width"]
+            if not points or len(points) < 2:
+                self.logger.warning("Skipping polyline with insufficient points: %s", polyline)
+                continue
+
+            # Create a shapely LineString from the points
+            line = shapely.geometry.LineString(points)
+            # Create a buffer around the line to create a polygon
+            if width <= 0:
+                self.logger.warning("Skipping polyline with non-positive width: %s", polyline)
+                continue
+
+            polygon = line.buffer(
+                width + Parameters.WATER_ADD_WIDTH, cap_style=shapely.geometry.CAP_STYLE.square
+            )
+            if polygon.is_empty:
+                self.logger.warning("Skipping empty polygon created from polyline: %s", polyline)
+                continue
+
+            # Ensure the polygon is valid and not empty
+            if not polygon.is_valid:
+                self.logger.warning("Invalid polygon created from polyline, skipping: %s", polyline)
+                continue
+
+            polygons.append(polygon)
+
+        fitted_polygons = []
+        for polygon in polygons:
+            try:
+                fitted_polygon_points = self.fit_object_into_bounds(
+                    polygon_points=polygon.exterior.coords,
+                    angle=self.rotation,
+                    canvas_size=self.background_size,
+                )
+                fitted_polygon = shapely.Polygon(fitted_polygon_points)
+                fitted_polygons.append(fitted_polygon)
+            except Exception as e:
+                self.logger.warning(
+                    "Could not fit polygon into bounds with error: %s, polygon: %s", e, polygon
+                )
+                continue
+
+        if not fitted_polygons:
+            self.logger.warning("No valid water polygons created from polylines.")
+            return
+
+        # Create a mesh from the 3D polygons
+        mesh = self.mesh_from_3d_polygons(fitted_polygons)
+        if mesh is None:
+            self.logger.warning("No mesh could be created from the water polygons.")
+            return
+        self.logger.debug("Created mesh from %s water polygons.", len(fitted_polygons))
+
+        mesh = self.rotate_mesh(mesh)
+        mesh = self.invert_faces(mesh)
+
+        line_based_save_path = os.path.join(self.water_directory, "line_based_water.obj")
+        mesh.export(line_based_save_path)
+        self.logger.debug("Line-based water mesh saved to %s", line_based_save_path)
+
+    def mesh_from_3d_polygons(self, polygons: list[shapely.Polygon]) -> Trimesh | None:
+        """Create a simple mesh from a list of 3D shapely Polygons.
+        Each polygon must be flat (all Z the same or nearly the same for each polygon).
+        Returns a single Trimesh mesh.
+
+        Arguments:
+            polygons (list[shapely.Polygon]): List of 3D shapely Polygons to create the mesh from.
+
+        Returns:
+            Trimesh: A single Trimesh object containing the mesh created from the polygons.
+        """
+
+        all_vertices = []
+        all_faces = []
+        vertex_offset = 0
+
+        not_resized_dem = cv2.imread(self.not_resized_path, cv2.IMREAD_UNCHANGED)
+
+        for polygon in polygons:
+            # Get exterior 3D coordinates
+            exterior_coords = np.array(polygon.exterior.coords)
+            # Project to 2D for triangulation
+            exterior_2d = exterior_coords[:, :2]
+            poly_2d = shapely.geometry.Polygon(
+                exterior_2d, [np.array(ring.coords)[:, :2] for ring in polygon.interiors]
+            )
+
+            # Triangulate in 2D
+            vertices_2d, faces = trimesh.creation.triangulate_polygon(poly_2d)
+            # tris.vertices is 2D, tris.faces are indices
+
+            # Map 2D triangulated vertices back to 3D by matching to original 3D coords
+            vertices_3d = []
+            for v in vertices_2d:
+                # Find closest original 2D point to get Z
+                dists = np.linalg.norm(exterior_2d - v[:2], axis=1)
+                idx = np.argmin(dists)
+                # z = exterior_coords[idx, 2]
+                z = self.get_z_coordinate_from_dem(
+                    not_resized_dem, exterior_coords[idx, 0], exterior_coords[idx, 1]  # type: ignore
+                )
+                vertices_3d.append([v[0], v[1], z])
+            vertices_3d = np.array(vertices_3d)  # type: ignore
+
+            faces = faces + vertex_offset
+            all_vertices.append(vertices_3d)
+            all_faces.append(faces)
+            vertex_offset += len(vertices_3d)
+
+        if not all_vertices:
+            return None
+
+        vertices = np.vstack(all_vertices)
+        faces = np.vstack(all_faces)
+        mesh = trimesh.Trimesh(vertices=vertices, faces=faces, process=False)
+        return mesh
+
     def generate_water_resources_obj(self) -> None:
         """Generates 3D obj files based on water resources data."""
+        self.logger.debug("Starting water resources generation...")
+        try:
+            self.generate_linebased_water()
+        except Exception as e:
+            self.logger.error("Error during line-based water generation: %s", e)
+
         if not os.path.isfile(self.water_resources_path):
             self.logger.warning("Water resources texture not found.")
             return
@@ -544,12 +687,12 @@ class Background(MeshComponent, ImageComponent):
         plane_water = cv2.imread(self.water_resources_path, cv2.IMREAD_UNCHANGED)
 
         # Check if the image contains non-zero values.
-        if not np.any(plane_water):
+        if not np.any(plane_water):  # type: ignore
             self.logger.debug("Water resources image is empty, skipping water generation.")
             return
 
         dilated_plane_water = cv2.dilate(
-            plane_water.astype(np.uint8), np.ones((5, 5), np.uint8), iterations=5
+            plane_water.astype(np.uint8), np.ones((5, 5), np.uint8), iterations=5  # type: ignore
         ).astype(np.uint8)
         plane_save_path = os.path.join(self.water_directory, "plane_water.obj")
         self.plane_from_np(dilated_plane_water, plane_save_path, include_zeros=False)
@@ -560,12 +703,12 @@ class Background(MeshComponent, ImageComponent):
         if self.map.output_size is not None:
             scaled_background_size = int(self.background_size * self.map.size_scale)
             plane_water = cv2.resize(
-                plane_water,
+                plane_water,  # type: ignore
                 (scaled_background_size, scaled_background_size),
                 interpolation=cv2.INTER_NEAREST,
             )
             background_dem = cv2.resize(
-                background_dem,
+                background_dem,  # type: ignore
                 (scaled_background_size, scaled_background_size),
                 interpolation=cv2.INTER_NEAREST,
             )
@@ -574,20 +717,20 @@ class Background(MeshComponent, ImageComponent):
             # Apply Gaussian blur to the background dem.
             blur_power = self._get_blur_power()
             background_dem = cv2.GaussianBlur(
-                background_dem, (blur_power, blur_power), sigmaX=blur_power, sigmaY=blur_power
+                background_dem, (blur_power, blur_power), sigmaX=blur_power, sigmaY=blur_power  # type: ignore
             )
 
         # Remove all the values from the background dem where the plane_water is 0.
-        background_dem[plane_water == 0] = 0
+        background_dem[plane_water == 0] = 0  # type: ignore
 
         # Dilate the background dem to make the water more smooth.
-        elevated_water = cv2.dilate(background_dem, np.ones((3, 3), np.uint16), iterations=10)
+        elevated_water = cv2.dilate(background_dem, np.ones((3, 3), np.uint16), iterations=10)  # type: ignore
 
         # Use the background dem as a mask to prevent the original values from being overwritten.
-        mask = background_dem > 0
+        mask = background_dem > 0  # type: ignore
 
         # Combine the dilated background dem with non-dilated background dem.
-        elevated_water = np.where(mask, background_dem, elevated_water)
+        elevated_water = np.where(mask, background_dem, elevated_water)  # type: ignore
         elevated_save_path = os.path.join(self.water_directory, "elevated_water.obj")
 
         self.assets.water_mesh = elevated_save_path
